all_package_extensions = [
	"bot_settings",
	"command_event",
	"connect_event",
	"error_handler",
	"help_command",
	"misc_commands",
	"owner_only",
	"redis_handler"
]